function [M,N,B] = InvUVW(A,XB)
//Calculation for M
//
// Calling Sequence
//   [M,N,B] = InvUVW(A,XB)  
//
// Parameters
//A : Coefficient Matrix (multidimensional matrix in case of multivariate polynomial) 
//XB : Original Bounds 
//M : Multiplication of Inverse of U,V and W matrix
//N : Dimension (Row) Matrix for all varibles in the Polynomial 
//B : Bernstein Coefficient of the Polynomial Over given bounds XB
//
// Description
// Matrix method is used to calculate M, N and B.
//
//Examples
// // Calculation for M
// [M,N,B] = InvUVW(A,XB)
// // If, A=[1,2;1,0] and XB=[0.5,1];
// // Gives ,
//   M(:).entries=[1,0.5;1,1], N=1, B=[1.5,2;2,2]
//
// Authors
//  Mr. Dhiraj B. Magare
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Mr. Bhagyesh V. Patil
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Prof. P.S.V. Nataraj
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay
//
// Bibliography
//1. Shashwati Ray, P.S.V. Nataraj. An efficient algorithm for range computation of polynomials using the Bernstein form. Journal of Global Optimization, 45: 403-426,2009;
//2. S. Ray, A new approach to range computation of polynomial problems using the Bernstein form. PhD thesis, Systems and Control Engineering, IIT Bombay, India, 2007.
//

  dim=size(XB,1);
  n=size(A)-1;
  if(length(n)>dim)    // this is necessary as for single dim problems length(size(A))=2 but length(N)=1  
    N=n(1);
  elseif(length(n)<dim)  // this is necessary as size(A) removes trailing singleton dimensions
    N=[n mtlb_zeros(1,dim-length(n))];
  else
    N=n;
  end
M=cell(1,dim);
for pp=1:dim,            //Upto dimension only
  kk=N(pp)+1;            // Power for each dimension
  if kk>0 then,
    InvU(1:kk,1)=1;InvU(1,2:kk)=0;InvU(kk,2:kk)=1; 
    for i=1:(kk-2),
         for j=1:i,
            InvU(i+1,j+1)=((factorial(i)/(factorial(i-j)*factorial(j)))/ (factorial(kk-1)/(factorial(j)*factorial(kk-1-j))));
          end
            InvU(i+1,i+2:kk)=0;
     end   


//y=InvU 
      widx=XB(pp,2)-XB(pp,1);
        InvV(1:kk,1:kk)=0;InvV(1,1)=1;
        s(1).entries=1;
        for i=2:kk,
          s(i).entries=(s(i-1).entries)*widx ;    
          InvV(i,i)=s(i).entries;     
        end    
       
      //y=InvV

      infx=min(XB(pp,1:2));  
        s(1).entries=1;
         for i=2:kk,
          s(i).entries=(s(i-1).entries)*infx ;    
          end  
         InvW(1,1)=1;
         for i=1:kk-1, 
           for j=i+1:kk,
            InvW(i,j)=(factorial(j-1)/(factorial(i-1)*factorial((j-1)-(i-1))))*(s(j+1-i).entries);
           end 
            InvW(i+1,1:i)=0;InvW(i+1,i+1)=1;
          end    
       
      //y=InvW
      M(pp).entries=InvU*InvV*InvW;
      InvU
      InvV
      InvW
      InvU=[];
      InvV=[];
      InvW=[];
   end //if kk>0 ....
end // for pp=....
M=M
B=A;
 if dim==1 then,
    B=M(1).entries*B;
  else
    for i=1:dim,
        // since n dim matrix mul is not possible reshaping to 2 dim mat then
        //multiplying and again reshaping back to original dim
        
        
        if i<=1 then,
          B=matrix( M(i).entries*matrix(B,N(i)+1,-1),[N(i:dim)+1 []]); 
         else
          B=matrix( M(i).entries*matrix(B,N(i)+1,-1),[N(i:dim)+1 N(1:i-1)+1]);
        end,  
        B=permute(B,[2:dim 1]);   // transpose for N dimensional matrix
     end,
   end,
B=B
endfunction;
