function [valid,flag,zcap]=cutoff(Bmin,zcap,flag,Bvermin)
// Cutoff Test
//
// Calling Sequence
//   [valid]=cutoff(Bmin,zcap,flag,Bvermin)  
//
// Parameters
//Bmin: Minimum Bernstein Coefficient Value
//zcap: Global Minimum Estimate
//flag: Number of Infeasible Boxes discarded
//Bvermin: Minimum Bernstein Coefficient Value at Vertices
//valid: Indicates boxes feasible (valid=1) or boxes infeasible (valid=0)
//
// Description
// This is an Accelerator Algorithm. Infeasible boxes removed during the process.
//
// Examples
// // Cutoff applied on current processing box.
// [valid]=cutoff(Bmin,zcap,flag,Bvermin) // This function only gives infeasible box's status 
// // Indicates boxes feasible (valid=1) or boxes infeasible (valid=0)
//
//
// See also
//  vertex
//  cutoff
// 
// Authors
//  Mr. Dhiraj B. Magare
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay ;
//
//  Mr. Bhagyesh V. Patil
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Prof. P.S.V. Nataraj
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay
//
// Bibliography
//1. Shashwati Ray, P.S.V. Nataraj. An efficient algorithm for range computation of polynomials using the Bernstein form. Journal of Global Optimization, 45: 403-426,2009;
//2.	G. T. Cargo and O. Shisha. The Bernstein form of a polynomial. Jl. of research of NBS,70B:79-81,1966.
//3. S. Ray, A new approach to range computation of polynomial problems using the Bernstein form. PhD thesis, Systems and Control Engineering, IIT Bombay, India, 2007.
//

      valid=1;      
     if Bmin>zcap then,
       flag=flag+1;            // Gives no. of infeasible soltions
       valid=0;
       return
     end,
    zcap=min(zcap,Bvermin);
endfunction;
