function [zcap,temp,Lsol,D1,temp1,ss,Lsol1,trial]=finalresult(D1,ex1,ex,zcap,LXsol) 
// Gives minimizers (Lsol) at which Global Minimum (zcap) estimate will lie
//
// Calling Sequence
//   [Lsol]=finalresult(D1,ex1,ex,zcap,LXsol)
//
// Parameters
//D1 : Total Number of Bvermin (minimum value at vertices)
//ex1 : Tolerence on Bounds
//ex : Tolerence on Global Minimum Estimate
//zcap: Global Minimum Estimate
// LXsol : All minimzers at which Global Minimum may lie
// Lsol : Final calculated minimzers at which Global Minimum will lie
//
// Description
// Finding out the global minimum and minimizers (bounds) for given polynomial function.
//
//Examples
// // Gives minimizers (Lsol) at which Global Minimum (zcap) estimate will lie.
// [Lsol]=finalresult(D1,ex1,ex,zcap,LXsol) 
// //Applying tolerance condition on list of LXsol and D1. This function returns Global Minimizers Lsol. 
//
// See also
//  vertex
//  store
//  
// Authors
//  Mr. Dhiraj B. Magare
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Mr. Bhagyesh V. Patil
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Prof. P.S.V. Nataraj
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay
// 
// Bibliography
//1. Shashwati Ray, P.S.V. Nataraj. An efficient algorithm for range computation of polynomials using the Bernstein form. Journal of Global Optimization, 45: 403-426,2009;
//2.	G. T. Cargo and O. Shisha. The Bernstein form of a polynomial. Jl. of research of NBS,70B:79-81,1966.
//3. S. Ray, A new approach to range computation of polynomial problems using the Bernstein form. PhD thesis, Systems and Control Engineering, IIT Bombay, India, 2007.
//

    Lsol=0;temp=0;sb=0;S1=0;S2=0;Lsol1=0;trial=0;
    [S1 S2]=size(D1);
    for f1=1:S1,
      if (D1(f1,1).entries >(zcap-ex1) & D1(f1,1).entries <(zcap+ex1)) then,
             sb=sb+1;
             temp(sb,1).entries=LXsol(f1,1).entries;
             trial(sb,1).entries=LXsol(f1,1).entries;
       end,
    end,
  //  [S1 S2]=size(temp);
    ss=1;
    temp1=0;
    for f2=2:sb,
       notsol=0;
      for f0=1:f2-1,
         sub1=temp(f2,1).entries; 
         sub2=temp(f0,1).entries; 
         if abs(sub1-sub2) < 0.01 then,   
           Lsol1(f2,1).entries=temp(f2,1).entries;
           notsol=1;
           break;
         end,
       end, //for f0=1:f2-1,
       if notsol==0 then,
          ss=ss+1;
          temp(ss,1).entries=temp(f2,1).entries;
       end,     
   end, // for f2=2:S1,  
     Lsol=temp(1:ss,1).entries;  
endfunction; 
