function [valid1,valid2,B1,B2,X1,X2,SubD,Bmin1,Bmin2,zcap,LXsol,Boxes,flag,D1,Z1,Y,X0,V,XV]=loop(B,X,A,ex1,zcap,N,Boxes,LXsol,D1,Z1,Y,flag)
// Maximum Width Property applied on given Polynomial function. 
//
// Description
// Application of Maximum Width Rule. Used for subdiving the box in the longest edge direction at the midpoint. This process generates two subdivided boxes. 
//
// These subdivided boxes undergo Vertex Property, and Cutoff Test.
//
//Examples
// // Maximum Width Property applied on given Polynomial function
// // Whichever box having maximum differece between lower and upper bounds, taken for subdivision process.
// // Like in this example say, 
//  X= [0,1;-1,2], //second row taken for process.
//
// See also
//  InvUVW
//  vertex
//  cutoff
//
// Authors
//  Mr. Dhiraj B. Magare
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Mr. Bhagyesh V. Patil
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Prof. P.S.V. Nataraj
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay
// 
// Bibliography
//1. Shashwati Ray, P.S.V. Nataraj. An efficient algorithm for range computation of polynomials using the Bernstein form. Journal of Global Optimization, 45: 403-426,2009;
//2.	G. T. Cargo and O. Shisha. The Bernstein form of a polynomial. Jl. of research of NBS,70B:79-81,1966.
//3. S. Ray, A new approach to range computation of polynomial problems using the Bernstein form. PhD thesis, Systems and Control Engineering, IIT Bombay, India, 2007.
//

    SubD=SubD+1; 
    valid1=0;valid2=0;qq1=0;
    //Maximum width property
      [m1 n1]=max([X(:,2)-X(:,1)]); // n1=index of maximum substraction box, m1=maximum substration 
       qq1=(X(n1,2)-X(n1,1));
       qrcap=X(n1,1)+(0.5*qq1);     // Mid Point Division
       X1=[X(n1,1) qrcap];     
       X2=[qrcap X(n1,2)];
       X(n1,:)=X1;
       X1=X;
       X(n1,:)=X2;
       X2=X;
       Boxes=Boxes+2;               //No. of Subdivided Boxes/Bounds
   [M,N,B1] = InvUVW(A,X1);
   [M,N,B2] = InvUVW(A,X2); 
   [valid1,Bmin1,Bvermin1,LXsol,zcap,D1,Z1,Y,X0,V,XV] = vertex(B1,X1,N,ex1,zcap,LXsol,D1,Z1,Y)
   [valid2,Bmin2,Bvermin2,LXsol,zcap,D1,Z1,Y,X0,V,XV] = vertex(B2,X2,N,ex1,zcap,LXsol,D1,Z1,Y)
   if valid1==1 then,
      [valid1,flag,zcap]=cutoff(Bmin1,zcap,flag,Bvermin1)      
   end,    
   if valid2==1 then,
      [valid2,flag,zcap]=cutoff(Bmin2,zcap,flag,Bvermin2)      
   end,  
endfunction;

