function [LXsol,Bvermin,zcap,D1,Z1,Y]= store(Y,Bvermin,zcap,LXsol,D1,Z1) 
// Stores Temporary Solution after the Vertex Property
//
// Calling Sequence
//   [LXsol,Bvermin,zcap,D1,Z1,Y]= store(Y,Bvermin,zcap,LXsol,D1,Z1)  
//
// Parameters
//Y : New Bounds Calculated from the Vertex Property
//Bvermin : Minimum Bersntein coefficient value at the Vertices
//zcap: Global Minimum Estimate
//LXsol: All minimzers at which Global minimum Estimate may lie
//D1: Total Number of Bernstein coefficients at the Vertices 
//Z1: Total Number of Global minimum Estimate (zcap)
//
// Description
// Updates the temporary solution list. 
//
//Examples
// // Stores Temporary Solution after the Vertex Property
// [LXsol,Bvermin,zcap,D1,Z1,Y]= store(Y,Bvermin,zcap,LXsol,D1,Z1) 
// // Temporary storage requires for calculation of final result. Without fail we must to store expected minimum with minimizers.
//
// See also
//  vertex
//  cutoff
//  
// Authors
//  Mr. Dhiraj B. Magare
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Mr. Bhagyesh V. Patil
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Prof. P.S.V. Nataraj
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay
// 

            [J1 J2]=size(LXsol);
            for i1=1:J1,
             if isempty(LXsol(i1,1).entries) then,
               LXsol(i1,1).entries=Y;
               D1(i1,1).entries=Bvermin;
               Z1(i1,1).entries=zcap;
               break;
             end,  
           end,
endfunction;
