function [b1,DA,DB] = subdirectionB(B,N)
//Calculation of B on Subdivided Boxes
//
// Calling Sequence
//   [b1,DA,DB] = subdirectionB(B,N)  
//
// Parameters
//B : Bernstein Coefficients on the given box  
//N : Dimensional (Row) Matrix for all Variables in the Polynomial
//b1 : Bernstein Coefficient after processing
//DA, DB : Bernstein coefficients on the Subdivided boxes XA and XB
//
//
// Description
// Using orginal Bernstein Coefficient patch, we can directly calculate Bernstein Coefficients on subdivided boxes.
//
// See also
//  InvUVW
//     
// Authors
//  Mr. Dhiraj B. Magare
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Mr. Bhagyesh V. Patil
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Prof. P.S.V. Nataraj
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay
//
// Bibliography
//1. Shashwati Ray, P.S.V. Nataraj. An efficient algorithm for range computation of polynomials using the Bernstein form. Journal of Global Optimization, 45: 403-426,2009;
//2. S. Ray, A new approach to range computation of polynomial problems using the Bernstein form. PhD thesis, Systems and Control Engineering, IIT Bombay, India, 2007.
//

[aa bb]=size(B); 
b1=zeros(aa,aa);
      b1(:,bb)=B;
      for i1=2:N+1,
        for j1=1:N+1,
           if j1<i1 then,
             b1(j1,i1)=b1(j1,i1-1);
           end,
           if j1>=i1 then,
             b1(j1,i1)=0.5*(b1(j1-1,i1-1)+b1(j1,i1-1));
           end,
        end,
      end,   
   b1=b1
   DA=b1(:,N+1);
   DB1=b1(N+1,:);
   DB=DB1($:-1:1)';   
endfunction;     
